Style Change: NULL->nullptr
DOCS_PREVIEW= https://skia.org/?cl=1316233002

Review URL: https://codereview.chromium.org/1316233002
diff --git a/tests/ChecksumTest.cpp b/tests/ChecksumTest.cpp
index 3658bd7..0302ea9 100644
--- a/tests/ChecksumTest.cpp
+++ b/tests/ChecksumTest.cpp
@@ -32,8 +32,8 @@
     for (size_t i = 0; i < SK_ARRAY_COUNT(kAlgorithms); ++i) {
         const algorithmProc algorithm = kAlgorithms[i];
 
-        // Hash of NULL is always 0.
-        ASSERT(algorithm(NULL, 0) == 0);
+        // Hash of nullptr is always 0.
+        ASSERT(algorithm(nullptr, 0) == 0);
 
         const uint32_t hash = algorithm(data, kBytes);
         // Should be deterministic.